.. documentation master file

************
Inequality
************

**inequality** implements measures for the analysis of inequality over space and time and is part of the  `PySAL family <https://pysal.org>`_

Details are available in the `inequality api <api.html>`_.

An Example: Spatial Inequality in Mexico: 1940-2000
============================================================

.. raw:: html

    <div class="container-fluid">
      <div class="row equal-height">
        <div class="col-sm-1 col-xs-hidden">
        </div>
        <div class="col-md-3 col-xs-12">
            <a href="http://nbviewer.jupyter.org/github/pysal/inequality/blob/main/notebooks/gini.ipynb" class="thumbnail">
                <img src="_static/images/1940.png" class="img-responsive center-block">
                <div class="caption text-center">
                <h6>State PC GDP 1940</h6>
                </div>
            </a>
        </div>
        <div class="col-sm-3 col-xs-12">
            <a href="http://nbviewer.jupyter.org/github/pysal/inequality/blob/main/notebooks/gini.ipynb" class="thumbnail">
                <img src="_static/images/regions.png" class="img-responsive center-block">
                <div class="caption text-center">
                <h6>Regions</h6>
                </div>
            </a>
        </div>
        <div class="col-sm-3 col-xs-12">
            <a href="http://nbviewer.jupyter.org/github/pysal/inequality/blob/main/notebooks/gini.ipynb" class="thumbnail">
                <img src="_static/images/share.png"
                class="img-responsive center-block">
                <div class="caption text-center">
                <h6>Gini (L) vs. Spatial Inequality Share (R)
                </h6>
                </div>
            </a>
        </div>
        <div class="col-sm-2 col-xs-hidden">
        </div>
      </div>
    </div>






Development
===========

inequality development is hosted on github_.

.. _github : https://github.com/pysal/inequality

Discussions of development occurs on the
`developer list <http://groups.google.com/group/pysal-dev>`_
as well as gitter_.

.. _gitter : https://gitter.im/pysal/pysal?


Getting Involved
======================

If you are interested in contributing to PySAL please see our
`development guidelines <http://pysal.readthedocs.org/en/latest/developers/index.html>`_.


Bug reports
===============

To search for or report bugs, please see inequality's issues_.

.. _issues :  http://github.com/pysal/inequality/issues


Citing inequality
==================

If you use PySAL-inequality in a scientific publication, we would appreciate citations to the following paper:

  `PySAL: A Python Library of Spatial Analytical Methods <http://journal.srsa.org/ojs/index.php/RRS/article/view/134/85>`_, *Rey, S.J. and L. Anselin*, Review of Regional Studies 37, 5-27 2007.

  Bibtex entry::

      @Article{pysal2007,
        author={Rey, Sergio J. and Anselin, Luc},
        title={{PySAL: A Python Library of Spatial Analytical Methods}},
        journal={The Review of Regional Studies},
        year=2007,
        volume={37},
        number={1},
        pages={5-27},
        keywords={Open Source; Software; Spatial}
      }




License information
========================

See the file "LICENSE.txt" for information on the history of this
software, terms & conditions for usage, and a DISCLAIMER OF ALL
WARRANTIES.


.. toctree::
   :hidden:
   :maxdepth: 4
   :caption: Contents:

   Installation <installation>
   Tutorials <tutorials>
   API <api>
   References <references>
   
.. _PySAL: https://github.com/pysal/pysal
